@@ -157,7 +157,7 @@ class Client:
         ## Get data row metadata with list of data row IDs
         data_row_metadata = lb_mdo.bulk_export(data_row_ids)
         endtime = datetime.now()
-        print(f'Laeblbox metadata export complete\n Start Time: {starttime}\n End Time: {endtime}\n Export Time: {endtime-starttime}\nData rows in export: {len(data_row_metadata)}')        
+        print(f'Labelbox metadata export complete\n Start Time: {starttime}\n End Time: {endtime}\n Export Time: {endtime-starttime}\nData rows in export: {len(data_row_metadata)}')        
         # Run the table through a UDF that will update metadata column values using the Global Key as the primary key        
         starttime = datetime.now()
         ## Create a dict where {metadata_field_name (column name) : {global_key : new_metadata_value}} (for enums, is the schema ID)
@@ -172,8 +172,9 @@ class Client:
                             upsert_dict[metadata_col] = {}
                         upsert_dict[metadata_col][data_row_id_to_global_key[str(data_row.data_row_id)]] = metadata_schema_to_name_key[field.value].split("///")[1] if field.value in metadata_schema_to_name_key.keys() else field.value
         ## For each metadata field column, use a UDF upsert column values with the values in your dict where {key=global_key : value=new_metadata_value}
-        for metadata_col in upsert_dict:               
-            spark_table.withColumn(metadata_col, connector.metadata_upsert_udf(upsert_dict_bytes=lit(json.dumps(upsert_dict[metadata_col])), global_key_col=global_key_col, metadata_value_col=metadata_col))
+        upsert_udf = connector.column_upsert_udf()
+        for metadata_col in upsert_dict:
+            spark_table.withColumn(metadata_col, upsert_udf(lit(json.dumps(upsert_dict[metadata_col])), global_key_col, metadata_col))
         endtime = datetime.now()
         print(f'Upsert table metadata complete\n Start Time: {starttime}\n End Time: {endtime}\n Total Time: {endtime-starttime}\nData rows upserted: {len(data_row_metadata)}') 
         return spark_table
@@ -194,6 +195,7 @@ class Client:
         starttime = datetime.now()
         lb_mdo = lb_client.get_data_row_metadata_ontology()
         metadata_schema_to_name_key = connector.get_metadata_schema_to_name_key(lb_mdo)
+        metadata_name_key_to_schema = connector.get_metadata_schema_to_name_key(lb_mdo, invert=True)
         ## Either use global_keys provided or all the global keys in the provided global_key column 
         global_keys = global_keys_list if global_keys_list else [str(x.__getitem__(global_key_col)) for x in spark_table.select(global_key_col).distinct().collect()]
         ## Grab data row IDs with global_key list
@@ -208,12 +210,17 @@ class Client:
         metadata_fields = list(metadata_index.keys())
         upload_metadata = []  
         for data_row in data_row_metadata:
+            global_key = data_row_id_to_global_key[str(data_row.data_row_id)]
+            print(f"global_key_col: {global_key_col}")
+            print(f"global_key: {global_key}")
             new_metadata = data_row.fields[:]
             for field in new_metadata:
                 field_name = metadata_schema_to_name_key[field.schema_id]
                 if field_name in metadata_fields:
-                    table_value = spark_table.filter(f"{global_key_col} = {data_row_id_to_global_key[str(data_row.data_row_id)]}").collect()[0].__getitem__(field_name)
-                    field.value = metadata_schema_to_name_key[table_value].split("///")[1] if table_value in metadata_schema_to_name_key.keys() else field.value
+                    print(f"field_name: {field_name}")
+                    table_value = spark_table.filter(f"{global_key_col} = {global_key}").collect()[0].__getitem__(field_name)
+                    table_name_key = f"{field_name}///{table_value}"
+                    field.value = metadata_name_key_to_schema[table_name_key] if table_name_key in metadata_name_key_to_schema.keys() else table_value
             upload_metadata.append(new_metadata)
         results = lb_mdo.bulk_upsert(upload_metadata)
         endtime = datetime.now()
